Learn R Programming

UNCOVER (version 1.1.0)

print.UNCOVER: Print UNCOVER

Description

Prints summary information from an UNCOVER object.

Usage

# S3 method for UNCOVER
print(x, ...)

Value

No return value, called for side effects

Arguments

x

Object of class "UNCOVER"

...

Further arguments passed to or from other methods

Details

When running the function UNCOVER() the printed information will contain information regarding; the number of clusters, the cluster sizes, the sub-model log Bayesian evidences and the total model log Bayesian evidence.

See Also

UNCOVER()